@@ -2,18 +2,17 @@ package ristretto
 
 import (
 	"testing"
+
+	"github.com/stretchr/testify/require"
 )
 
 func TestSketch(t *testing.T) {
 	defer func() {
-		if r := recover(); r == nil {
-			t.Fatal("no panic with bad param numCounters")
-		}
+		require.NotNil(t, recover())
 	}()
+
 	s := newCmSketch(5)
-	if s.mask != 7 {
-		t.Fatal("not rounding up to next power of 2")
-	}
+	require.Equal(t, uint64(7), s.mask)
 	newCmSketch(0)
 }
 
@@ -26,9 +25,7 @@ func TestSketchIncrement(t *testing.T) {
 		if s.rows[i].string() != s.rows[0].string() {
 			break
 		}
-		if i == cmDepth-1 {
-			t.Fatal("identical rows, bad seeding")
-		}
+		require.False(t, i == cmDepth-1, "identical rows, bad seeding")
 	}
 }
 
@@ -36,12 +33,8 @@ func TestSketchEstimate(t *testing.T) {
 	s := newCmSketch(16)
 	s.Increment(1)
 	s.Increment(1)
-	if s.Estimate(1) != 2 {
-		t.Fatal("estimate should be 2")
-	}
-	if s.Estimate(0) != 0 {
-		t.Fatal("estimate should be 0")
-	}
+	require.Equal(t, int64(2), s.Estimate(1))
+	require.Equal(t, int64(0), s.Estimate(0))
 }
 
 func TestSketchReset(t *testing.T) {
@@ -51,9 +44,7 @@ func TestSketchReset(t *testing.T) {
 	s.Increment(1)
 	s.Increment(1)
 	s.Reset()
-	if s.Estimate(1) != 2 {
-		t.Fatal("reset failed, estimate should be 2")
-	}
+	require.Equal(t, int64(2), s.Estimate(1))
 }
 
 func TestSketchClear(t *testing.T) {
@@ -63,9 +54,7 @@ func TestSketchClear(t *testing.T) {
 	}
 	s.Clear()
 	for i := 0; i < 16; i++ {
-		if s.Estimate(uint64(i)) != 0 {
-			t.Fatal("clear failed")
-		}
+		require.Equal(t, int64(0), s.Estimate(uint64(i)))
 	}
 }
 
